.. :changelog:

History
-------

0.6.0 (2016-08-15)
++++++++++++++++++
- Order preserving parameter objects
- Fixing logging issue
- Prettified examples


0.5.0 (2015-05-12)
++++++++++++++++++
- Flat package structure
- Separation of sampling and modules
- improved documentation

0.4.0 (2015-03-16)
++++++++++++++++++
- Support for Python 3
- Change in package structure
- Fixed bug in mpi pso

0.3.0 (2014-03-22)
++++++++++++++++++
- Better exception handling
- Particle swarm optimization module
- Higher test coverage
- Some bug fixes
- Extended documentation
- Support for PyCamb

0.2.1 (2013-09-05)
++++++++++++++++++
- Some bug fixes

0.2.0 (2013-08-28)
++++++++++++++++++
- Revised version - not backwards compatible!
- Bug fixes and major code refactoring
- New documentation

0.1.0 (2013-01-03)
++++++++++++++++++
- First release

0.0.3 (2012-11-23)
++++++++++++++++++
- First release candidate

0.0.1 (2012-05-09)
++++++++++++++++++
- Initial creation


